@@ -38,6 +38,11 @@ int main(int argc, char *argv[])
     a->setApplicationName("dtk-example");
     a->setOrganizationName("deepin");
     a->setApplicationVersion("1.0");
+    a->setProductIcon(QIcon(":/images/logo_icon.svg"));
+    a->setWindowIcon(QIcon(":/images/logo_icon.svg"));
+    a->setApplicationDescription(QApplication::translate("main", "Collections provides the examples for dtk applications."));
+    a->setApplicationDisplayName(QObject::tr("Collections"));
+    a->setApplicationLicense(QObject::tr("2023 UnionTech Software Technology Co., Ltd."));
 
     DApplicationSettings as;
     Q_UNUSED(as)
