@@ -13,6 +13,7 @@
 #include <QPainter>
 #include <QIconEngine>
 #include <QStyleOption>
+#include <QApplication>
 
 QT_BEGIN_NAMESPACE
 class QTextLayout;
@@ -135,6 +136,7 @@ public:
         PM_ContentsMargins,                                     //内容的边距（一般只用于左右边距）
         PM_ContentsSpacing,                                     //内容的间距（可用于列表项中每一项的距离）
         PM_ButtonMinimizedSize,                                 //按钮控件的最小大小
+        PM_ToolTipLabelWidth,                                   // Maximum width that a ToolTip label can reach
         PM_CustomBase = QStyle::PM_CustomBase + 0xf00000
     };
 
@@ -216,12 +218,13 @@ public:
     static QPair<QIcon::Mode, QIcon::State> toIconModeState(const QStyleOption *option);
     static DDciIcon::Mode toDciIconMode(const QStyleOption *option);
 
-    static void setTooltipTextFormat(Qt::TextFormat format);
-    static Qt::TextFormat tooltipTextFormat();
+    D_DECL_DEPRECATED_X("Use DToolTip::setToolTipTextFormat(Qt::TextFormat format)") static void setTooltipTextFormat(Qt::TextFormat format);
+    D_DECL_DEPRECATED_X("Use DToolTip::toolTipTextFormat()") static Qt::TextFormat tooltipTextFormat();
     static DStyle::StyleState getState(const QStyleOption *option);
     static void setFocusRectVisible(QWidget *widget, bool visible);
     static void setFrameRadius(QWidget *widget, int radius);
     static void setUncheckedItemIndicatorVisible(QWidget *widget, bool visible);
+    static void setRedPointVisible(QObject *object, bool visible);
     DStyle();
 
     static void drawPrimitive(const QStyle *style, DStyle::PrimitiveElement pe, const QStyleOption *opt, QPainter *p, const QWidget *w = nullptr);
@@ -301,7 +304,7 @@ public:
 class DStyleHelper
 {
 public:
-    inline DStyleHelper(const QStyle *style = nullptr) {
+    inline DStyleHelper(const QStyle *style = QApplication::style()) {
         setStyle(style);
     }
 
