@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2015 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2015 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include <QtGlobal>
 #ifdef Q_OS_LINUX
@@ -53,7 +40,9 @@
 #include "dthememanager.h"
 #include "private/dapplication_p.h"
 #include "daboutdialog.h"
+#include "dfeaturedisplaydialog.h"
 #include "dmainwindow.h"
+#include "dsizemode.h"
 
 #include <DPlatformHandle>
 #include <DGuiApplicationHelper>
@@ -61,7 +50,7 @@
 #include <DTitlebar>
 
 #ifdef Q_OS_LINUX
-#include "startupnotificationmonitor.h"
+#include "private/startupnotifications/startupnotificationmonitor.h"
 
 #include <DDBusSender>
 
@@ -247,7 +236,7 @@ bool DApplicationPrivate::loadDtkTranslator(QList<QLocale> localeFallback)
     qtTranslator->load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     q->installTranslator(qtbaseTranslator);
 
-    QList<DPathBuf> translateDirs;
+    QList<QString> translateDirs;
     auto dtkwidgetDir = DWIDGET_TRANSLATIONS_DIR;
     auto dtkwidgetName = "dtkwidget";
 
@@ -255,73 +244,14 @@ bool DApplicationPrivate::loadDtkTranslator(QList<QLocale> localeFallback)
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const auto &path : dataDirs) {
         DPathBuf DPathBuf(path);
-        translateDirs << DPathBuf / dtkwidgetDir;
+        translateDirs << (DPathBuf / dtkwidgetDir).toString();
     }
 
-    DPathBuf runDir(q->applicationDirPath());
-    translateDirs << runDir.join("translations");
-
-    DPathBuf currentDir(QDir::currentPath());
-    translateDirs << currentDir.join("translations");
-
 #ifdef DTK_STATIC_TRANSLATION
-    translateDirs << DPathBuf(":/dtk/translations");
+    translateDirs << QString(":/dtk/translations");
 #endif
 
-    return loadTranslator(translateDirs, dtkwidgetName, localeFallback);
-}
-
-bool DApplicationPrivate::loadTranslator(QList<DPathBuf> translateDirs, const QString &name, QList<QLocale> localeFallback)
-{
-    D_Q(DApplication);
-
-    QStringList missingQmfiles;
-    for (auto &locale : localeFallback) {
-        QString translateFilename = QString("%1_%2").arg(name).arg(locale.name());
-        for (auto &path : translateDirs) {
-            QString translatePath = (path / translateFilename).toString();
-            if (QFile::exists(translatePath + ".qm")) {
-                qDebug() << "load translate" << translatePath;
-                auto translator = new QTranslator(q);
-                translator->load(translatePath);
-                q->installTranslator(translator);
-                q->setProperty("dapp_locale", locale.name());
-                return true;
-            }
-        }
-
-        // fix english does not need to translation..
-        if (locale.language() != QLocale::English) {
-            missingQmfiles << translateFilename + ".qm";
-        }
-
-        QStringList parseLocalNameList = locale.name().split("_", QString::SkipEmptyParts);
-        if (parseLocalNameList.length() > 0) {
-            translateFilename = QString("%1_%2").arg(name)
-                                .arg(parseLocalNameList.at(0));
-            for (auto &path : translateDirs) {
-                QString translatePath = (path / translateFilename).toString();
-                if (QFile::exists(translatePath + ".qm")) {
-                    qDebug() << "translatePath after feedback:" << translatePath;
-                    auto translator = new QTranslator(q);
-                    translator->load(translatePath);
-                    q->installTranslator(translator);
-                    q->setProperty("dapp_locale", parseLocalNameList.at(0));
-                    return true;
-                }
-            }
-        }
-
-        // fix english does not need to translation..
-        if (locale.language() != QLocale::English) {
-            missingQmfiles << translateFilename + ".qm";
-        }
-    }
-
-    if (missingQmfiles.size() > 0) {
-        qWarning() << name << "can not find qm files" << missingQmfiles;
-    }
-    return false;
+    return DGuiApplicationHelper::loadTranslator(dtkwidgetName, translateDirs, localeFallback);
 }
 
 // 自动激活DMainWindow类型的窗口
@@ -459,6 +389,29 @@ void DApplicationPrivate::_q_resizeWindowContentsForVirtualKeyboard()
     acclimatizeVirtualKeyboardForFocusWidget(false);
 }
 
+void DApplicationPrivate::_q_sizeModeChanged()
+{
+    QEvent ev(QEvent::StyleChange);
+    for (auto item : qApp->topLevelWidgets()) {
+        handleSizeModeChangeEvent(item, &ev);
+    }
+}
+
+void DApplicationPrivate::handleSizeModeChangeEvent(QWidget *widget, QEvent *event)
+{
+    // 深度优先遍历，事件接受顺序：子 -> 父， 若parentWidget先处理event，可能存在布局没更新问题
+    for (auto w : widget->findChildren<QWidget *>(QString(), Qt::FindDirectChildrenOnly)) {
+        handleSizeModeChangeEvent(w, event);
+    }
+    if (widget->isTopLevel()) {
+        // TODO 顶层窗口需要延迟，否则内部控件布局出现异常，例如DDialog, 若send事件，导致
+        // 从compact -> normal -> campact时，DDialog内部控件布局的两次campact大小不一致.
+        qApp->postEvent(widget, new QEvent(*event));
+    } else {
+        QCoreApplication::sendEvent(widget, event);
+    }
+}
+
 bool DApplicationPrivate::isUserManualExists()
 {
     return DGuiApplicationHelper::instance()->hasUserManual();
@@ -648,6 +601,9 @@ DApplication::DApplication(int &argc, char **argv) :
             QTapAndHoldGesture::setTimeout(gsettings.get("longpress-duration").toInt() - 100);
     }
 #endif
+
+    connect(DGuiApplicationHelper::instance(), SIGNAL(sizeModeChanged(DGuiApplicationHelper::SizeMode)),
+            this, SLOT(_q_sizeModeChanged()));
 }
 
 /*!
@@ -792,24 +748,20 @@ bool DApplication::loadTranslator(QList<QLocale> localeFallback)
 
     d->loadDtkTranslator(localeFallback);
 
-    QList<DPathBuf> translateDirs;
+    QList<QString> translateDirs;
     auto appName = applicationName();
     //("/home/user/.local/share", "/usr/local/share", "/usr/share")
     auto dataDirs = DStandardPaths::standardLocations(QStandardPaths::GenericDataLocation);
     for (const auto &path : dataDirs) {
         DPathBuf DPathBuf(path);
-        translateDirs << DPathBuf / appName / "translations";
+        translateDirs << (DPathBuf / appName / "translations").toString();
     }
-    DPathBuf runDir(this->applicationDirPath());
-    translateDirs << runDir.join("translations");
-    DPathBuf currentDir(QDir::currentPath());
-    translateDirs << currentDir.join("translations");
 
 #ifdef DTK_STATIC_TRANSLATION
-    translateDirs << DPathBuf(":/dtk/translations");
+    translateDirs << QString(":/dtk/translations");
 #endif
 
-    return d->loadTranslator(translateDirs, appName, localeFallback);
+    return DGuiApplicationHelper::loadTranslator(appName, translateDirs, localeFallback);
 }
 
 /*!
@@ -1155,6 +1107,26 @@ void DApplication::setAboutDialog(DAboutDialog *aboutDialog)
     d->aboutDialog = aboutDialog;
 }
 
+DFeatureDisplayDialog *DApplication::featureDisplayDialog()
+{
+    D_D(DApplication);
+    if (d->featureDisplayDialog == nullptr) {
+        d->featureDisplayDialog = new DFeatureDisplayDialog(activeWindow());
+    }
+    return d->featureDisplayDialog;
+}
+
+void DApplication::setFeatureDisplayDialog(DFeatureDisplayDialog *featureDisplayDialog)
+{
+    D_D(DApplication);
+
+    if (d->featureDisplayDialog && d->featureDisplayDialog != featureDisplayDialog) {
+        d->featureDisplayDialog->deleteLater();
+    }
+
+    d->featureDisplayDialog = featureDisplayDialog;
+}
+
 /*!
   \property DApplication::visibleMenuShortcutText
 
@@ -1440,7 +1412,9 @@ void DApplication::handleAboutAction()
     connect(d->aboutDialog, &DAboutDialog::destroyed, this, [=] {
         d->aboutDialog = nullptr;
     });
-
+    connect(d->aboutDialog, &DAboutDialog::featureActivated, this, [this] {
+        featureDisplayDialog()->show();
+    });
     if (DGuiApplicationHelper::isTabletEnvironment()) {
         aboutDialog->exec();
     } else {
