@@ -1,26 +1,15 @@
-/*
- * Copyright (C) 2017 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dmainwindow.h"
 #include "dplatformwindowhandle.h"
 #include "dapplication.h"
 #include "dtitlebar.h"
 #include "dmessagemanager.h"
-
+#include "DBlurEffectWidget"
+#include "dsizemode.h"
+#include "dfeaturedisplaydialog.h"
 #include "private/dmainwindow_p.h"
 #include "private/dapplication_p.h"
 
@@ -29,6 +18,12 @@
 #include <QWindow>
 #include <QMouseEvent>
 #include <QComboBox>
+#include <QToolBar>
+#include <QVBoxLayout>
+#include <qwidgetaction.h>
+#include <QScreen>
+
+#include <DConfig>
 
 #ifdef Q_OS_MAC
 #include "osxwindow.h"
@@ -45,7 +40,12 @@ DMainWindowPrivate::DMainWindowPrivate(DMainWindow *qq)
 {
     titlebar = new DTitlebar(qq);
     titlebar->setAccessibleName("DMainWindowTitlebar");
-    if (DApplication::isDXcbPlatform()) {
+    auto noTitlebarEnabled = []{
+        QFunctionPointer enableNoTitlebar = qApp->platformFunction("_d_isEnableNoTitlebar");
+        bool enabled = qApp->platformName() == "dwayland" || qApp->property("_d_isDwayland").toBool();
+        return enabled && enableNoTitlebar != nullptr;
+    };
+    if (DApplication::isDXcbPlatform() || noTitlebarEnabled()) {
         handle = new DPlatformWindowHandle(qq, qq);
         qq->setMenuWidget(titlebar);
     } else {
@@ -112,7 +112,7 @@ void DMainWindowPrivate::init()
         QObject::connect(help, &QShortcut::activated,
         q, [ = ]() {
             DApplication *dapp = qobject_cast<DApplication *>(qApp);
-            if (dapp && DApplicationPrivate::isUserManualExists()) {
+            if (dapp) {
                 dapp->handleHelpAction();
             }
         });
@@ -126,28 +126,48 @@ void DMainWindowPrivate::updateTitleShadowGeometry()
     if (!titleShadow)
         return;
 
-    QRect rect(0, titlebar->geometry().bottom() + 1, q->width(), titleShadow->sizeHint().height());
+    int x = (sidebarHelper && sidebarHelper->expanded()) ? sidebarHelper->width() : 0;
+    QRect rect(x, titlebar->geometry().bottom() + 1, q->width(), titleShadow->sizeHint().height());
     titleShadow->setGeometry(rect);
     // 全凭时会隐藏窗口标题栏，因此不应该显示标题栏的阴影
     titleShadow->setVisible(!q->isFullScreen());
     titleShadow->raise();
 }
 
+void DMainWindowPrivate::_q_autoShowFeatureDialog()
+{
+    D_QC(DMainWindow);
+    if (q->windowHandle()->isActive()) {
+        qApp->featureDisplayDialog()->show();
+        const QPoint pos = q->pos();
+        QRect rect;
+        for (QScreen *screen : qApp->screens()) {
+            if (screen->geometry().contains(pos)) {
+                rect = screen->geometry();
+                break;
+            }
+        }
+        qApp->featureDisplayDialog()->moveToCenterByRect(rect);
+        q->disconnect(q->windowHandle(), SIGNAL(activeChanged()), q, SLOT(_q_autoShowFeatureDialog()));
+    }
+}
+
 /*!
- * \class DMainWindow
- * \brief The DMainWindow class provides a main application window.
- *
- * A main window provides a framework for building an application's user
- * interface. DMainWindow has its own layout compared to QMainWindow,
- * it has only title bar and content area, simpler and cleaner.
- *
- * Developers can provide customized title bar and content to make the
- * application rich functional.
+  \class Dtk::Widget::DMainWindow
+  \inmodule dtkwidget
+  \brief The DMainWindow class provides a main application window.
+  
+  A main window provides a framework for building an application's user
+  interface. DMainWindow has its own layout compared to QMainWindow,
+  it has only title bar and content area, simpler and cleaner.
+  
+  Developers can provide customized title bar and content to make the
+  application rich functional.
  */
 
 /*!
- * \brief DMainWindow::DMainWindow constructs an instance of DMainWindow
- * \param parent is passed to QMainWindow construtor.
+  \brief DMainWindow::DMainWindow constructs an instance of DMainWindow
+  \a parent is passed to QMainWindow construtor.
  */
 DMainWindow::DMainWindow(QWidget *parent)
     : QMainWindow(parent)
@@ -159,11 +179,17 @@ DMainWindow::DMainWindow(QWidget *parent)
     if (DGuiApplicationHelper::isTabletEnvironment()) {
         setWindowFlags(windowFlags() & ~(Qt::WindowMinMaxButtonsHint | Qt::WindowCloseButtonHint));
     }
+    DConfig config("org.deepin.dtkwidget.feature-display");
+    bool isAutoDisplayFeature = config.value("autoDisplayFeature", false).toBool();
+    if (isAutoDisplayFeature) {
+        connect(this->windowHandle(), SIGNAL(activeChanged()), this, SLOT(_q_autoShowFeatureDialog()));
+        config.setValue("autoDisplayFeature", false);
+    }
 }
 
 /*!
- * \brief DMainWindow::titlebar
- * \return a DTitlebar instance used by the main window.
+  \brief DMainWindow::titlebar
+  \return a DTitlebar instance used by the main window.
  */
 DTitlebar *DMainWindow::titlebar() const
 {
@@ -172,12 +198,94 @@ DTitlebar *DMainWindow::titlebar() const
     return d->titlebar;
 }
 
+void DMainWindow::setSidebarWidget(QWidget *widget)
+{
+    D_D(DMainWindow);
+    if (d->sidebarWidget == widget)
+        return;
+
+    d->sidebarWidget = widget;
+    d->sidebarWidget->setAutoFillBackground(true);
+    d->sidebarWidget->setBackgroundRole(DPalette::Button);
+    if (!d->sidebarHelper) {
+        d->sidebarHelper = new DSidebarHelper(this);
+        d->titlebar->setSidebarHelper(d->sidebarHelper);
+        QToolBar *tb = new QToolBar(this);
+        tb->setMovable(false);
+        tb->setForegroundRole(QPalette::Base);
+        auto *contentAction = tb->toggleViewAction();
+        contentAction->setVisible(false);
+        addToolBar(Qt::LeftToolBarArea, tb);
+        widget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+        QWidgetAction *action = static_cast<QWidgetAction *>(tb->addWidget(widget));
+        widget->resize(tb->size());
+        qInfo() << "actionGeometry" << tb->actionGeometry(action);
+
+        connect(d->sidebarHelper, &DSidebarHelper::widthChanged, tb, &QToolBar::setFixedWidth);
+        connect(d->sidebarHelper, &DSidebarHelper::expandChanged, this, [tb, d] (bool expanded) {
+            tb->setVisible(expanded);
+            d->updateTitleShadowGeometry();
+        });
+        connect(d->sidebarHelper, &DSidebarHelper::visibleChanged, tb, &QToolBar::setVisible);
+        d->tb = tb;
+    }
+
+}
+
+QWidget *DMainWindow::sidebarWidget()
+{
+    D_DC(DMainWindow);
+    return d->sidebarWidget;
+}
+
+int DMainWindow::sidebarWidth() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->width();
+}
+
+void DMainWindow::setSidebarWidth(int width)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setWidth(width);
+}
+
+bool DMainWindow::sidebarVisble() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->visble();
+}
+
+void DMainWindow::setSidebarVisible(bool visible)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setVisible(visible);
+}
+
+bool DMainWindow::sidebarExpanded() const
+{
+    D_DC(DMainWindow);
+    if (d->sidebarHelper)
+        return d->sidebarHelper->expanded();
+}
+
+void DMainWindow::setSidebarExpanded(bool expended)
+{
+    D_D(DMainWindow);
+    if (d->sidebarHelper)
+        d->sidebarHelper->setExpanded(expended);
+}
+
 /*!
- * \brief DMainWindow::isDXcbWindow
- * \return Whether this window is dxcb backended.
- *
- * Many features like blurred background and window clipping are supported
- * only if the window is using the dxcb Qt platform plugin.
+  \brief DMainWindow::isDXcbWindow
+  \return Whether this window is dxcb backended.
+  
+  Many features like blurred background and window clipping are supported
+  only if the window is using the dxcb Qt platform plugin.
  */
 bool DMainWindow::isDXcbWindow() const
 {
@@ -187,8 +295,8 @@ bool DMainWindow::isDXcbWindow() const
 }
 
 /*!
- * \property DMainWindow::windowRadius
- * \brief This property holds the radius of the main window.
+  \property DMainWindow::windowRadius
+  \brief This property holds the radius of the main window.
  */
 int DMainWindow::windowRadius() const
 {
@@ -202,8 +310,8 @@ int DMainWindow::windowRadius() const
 }
 
 /*!
- * \property DMainWindow::borderWidth
- * \brief This property holds the width of the main window's border.
+  \property DMainWindow::borderWidth
+  \brief This property holds the width of the main window's border.
  */
 int DMainWindow::borderWidth() const
 {
@@ -217,8 +325,8 @@ int DMainWindow::borderWidth() const
 }
 
 /*!
- * \property DMainWindow::borderColor
- * \brief This property holds the color of the main window's border.
+  \property DMainWindow::borderColor
+  \brief This property holds the color of the main window's border.
  */
 QColor DMainWindow::borderColor() const
 {
@@ -232,8 +340,8 @@ QColor DMainWindow::borderColor() const
 }
 
 /*!
- * \property DMainWindow::shadowRadius
- * \brief This property holds the shadow radius of the main widnow.
+  \property DMainWindow::shadowRadius
+  \brief This property holds the shadow radius of the main widnow.
  */
 int DMainWindow::shadowRadius() const
 {
@@ -247,8 +355,8 @@ int DMainWindow::shadowRadius() const
 }
 
 /*!
- * \property DMainWindow::shadowOffset
- * \brief This property holds the offset applied on the window shadow.
+  \property DMainWindow::shadowOffset
+  \brief This property holds the offset applied on the window shadow.
  */
 QPoint DMainWindow::shadowOffset() const
 {
@@ -262,8 +370,8 @@ QPoint DMainWindow::shadowOffset() const
 }
 
 /*!
- * \property DMainWindow::shadowColor
- * \brief This property holds the color of the window shadow.
+  \property DMainWindow::shadowColor
+  \brief This property holds the color of the window shadow.
  */
 QColor DMainWindow::shadowColor() const
 {
@@ -277,13 +385,13 @@ QColor DMainWindow::shadowColor() const
 }
 
 /*!
- * \property DMainWindow::clipPath
- * \brief This property holds the custom QPainterPath to be used to clip the window.
- *
- * By default DMainWindow is clipped as a corner-rounded rectangle, but you can
- * supply a custom QPainterPath to do custom shaped window.
- *
- * \see DMainWindow::frameMask
+  \property DMainWindow::clipPath
+  \brief This property holds the custom QPainterPath to be used to clip the window.
+  
+  By default DMainWindow is clipped as a corner-rounded rectangle, but you can
+  supply a custom QPainterPath to do custom shaped window.
+  
+  \sa DMainWindow::frameMask
  */
 QPainterPath DMainWindow::clipPath() const
 {
@@ -297,11 +405,11 @@ QPainterPath DMainWindow::clipPath() const
 }
 
 /*!
- * \property DMainWindow::frameMask
- * \brief This property holds the mask to be applied on the window.
- *
- * For better clip quality, for example antialiasing, use property
- * DMainWindow::clipPath instead.
+  \property DMainWindow::frameMask
+  \brief This property holds the mask to be applied on the window.
+  
+  For better clip quality, for example antialiasing, use property
+  DMainWindow::clipPath instead.
  */
 QRegion DMainWindow::frameMask() const
 {
@@ -326,8 +434,8 @@ QMargins DMainWindow::frameMargins() const
 }
 
 /*!
- * \property DMainWindow::translucentBackground
- * \brief This property holds whether the window has translucent background.
+  \property DMainWindow::translucentBackground
+  \brief This property holds whether the window has translucent background.
  */
 bool DMainWindow::translucentBackground() const
 {
@@ -341,13 +449,13 @@ bool DMainWindow::translucentBackground() const
 }
 
 /*!
- * \brief DMainWindow::enableSystemResize
- * \return This property holds whether the window can be resized by the user.
- *
- * The default value of this property is true.
- *
- * You can set this property to false and implement the resize polizy of this
- * window by you self.
+  \brief DMainWindow::enableSystemResize
+  \return This property holds whether the window can be resized by the user.
+  
+  The default value of this property is true.
+  
+  You can set this property to false and implement the resize polizy of this
+  window by you self.
  */
 bool DMainWindow::enableSystemResize() const
 {
@@ -361,12 +469,12 @@ bool DMainWindow::enableSystemResize() const
 }
 
 /*!
- * \property DMainWindow::enableSystemMove
- * \brief This property holds whether the window can be moved by the user.
- *
- * The default value of this property is true.
- *
- * You can set this property to false and choose the effective area to drag and move.
+  \property DMainWindow::enableSystemMove
+  \brief This property holds whether the window can be moved by the user.
+  
+  The default value of this property is true.
+  
+  You can set this property to false and choose the effective area to drag and move.
  */
 bool DMainWindow::enableSystemMove() const
 {
@@ -380,8 +488,8 @@ bool DMainWindow::enableSystemMove() const
 }
 
 /*!
- * \property DMainWindow::enableBlurWindow
- * \brief This property holds whether the window background is blurred.
+  \property DMainWindow::enableBlurWindow
+  \brief This property holds whether the window background is blurred.
  */
 bool DMainWindow::enableBlurWindow() const
 {
@@ -395,13 +503,13 @@ bool DMainWindow::enableBlurWindow() const
 }
 
 /*!
- * \property DMainWindow::autoInputMaskByClipPath
- * \brief This property holds whether the user input is masked by the clip path.
- *
- * Sometimes you may want to handle events happening in the areas that are
- * visually clipped by the setting DMainWindow::clipPath.
- *
- * The default value of this property is true.
+  \property DMainWindow::autoInputMaskByClipPath
+  \brief This property holds whether the user input is masked by the clip path.
+  
+  Sometimes you may want to handle events happening in the areas that are
+  visually clipped by the setting DMainWindow::clipPath.
+  
+  The default value of this property is true.
  */
 bool DMainWindow::autoInputMaskByClipPath() const
 {
@@ -414,9 +522,13 @@ bool DMainWindow::autoInputMaskByClipPath() const
     return d->handle->autoInputMaskByClipPath();
 }
 
+
 /*!
- * \~chinese \brief DMainWindow::titlebarShadowIsEnabled
- * \~chinese \return true　titleBar阴影开启　false 阴影关闭
+    \property DMainWindow::titlebarShadowEnabled
+    \brief titleBar阴影属性.
+
+    用于设置或者判断是否设置titleBar阴影属性.
+
  */
 bool DMainWindow::titlebarShadowIsEnabled() const
 {
@@ -426,8 +538,8 @@ bool DMainWindow::titlebarShadowIsEnabled() const
 }
 
 /*!
- * \~chinese \brief DMainWindow::setWindowRadius　设定窗口的圆角
- * \~chinese \param windowRadius　窗口的圆角值
+  \brief DMainWindow::setWindowRadius　设定窗口的圆角
+  \a windowRadius　窗口的圆角值
  */
 void DMainWindow::setWindowRadius(int windowRadius)
 {
@@ -441,8 +553,8 @@ void DMainWindow::setWindowRadius(int windowRadius)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setBorderWidth 设定边框的宽度
- * \~chinese \param borderWidth　边框的宽度
+  \brief DMainWindow::setBorderWidth 设定边框的宽度
+  \a borderWidth　边框的宽度
  */
 void DMainWindow::setBorderWidth(int borderWidth)
 {
@@ -456,8 +568,8 @@ void DMainWindow::setBorderWidth(int borderWidth)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setBorderColor 设定边框的颜色
- * \~chinese \param borderColor　边框的颜色
+  \brief DMainWindow::setBorderColor 设定边框的颜色
+  \a borderColor　边框的颜色
  */
 void DMainWindow::setBorderColor(const QColor &borderColor)
 {
@@ -471,8 +583,8 @@ void DMainWindow::setBorderColor(const QColor &borderColor)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setShadowRadius 设定阴影区域的圆角
- * \~chinese \param shadowRadius　阴影区域圆角大小
+  \brief DMainWindow::setShadowRadius 设定阴影区域的圆角
+  \a shadowRadius　阴影区域圆角大小
  */
 void DMainWindow::setShadowRadius(int shadowRadius)
 {
@@ -486,8 +598,8 @@ void DMainWindow::setShadowRadius(int shadowRadius)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setShadowOffset 设定阴影区域的偏移距离
- * \~chinese \param shadowOffset　阴影区域的偏移距离
+  \brief DMainWindow::setShadowOffset 设定阴影区域的偏移距离
+  \a shadowOffset　阴影区域的偏移距离
  */
 void DMainWindow::setShadowOffset(const QPoint &shadowOffset)
 {
@@ -501,8 +613,8 @@ void DMainWindow::setShadowOffset(const QPoint &shadowOffset)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setShadowColor 设定阴影的颜色
- * \~chinese \param shadowColor　阴影的颜色
+  \brief DMainWindow::setShadowColor 设定阴影的颜色
+  \a shadowColor　阴影的颜色
  */
 void DMainWindow::setShadowColor(const QColor &shadowColor)
 {
@@ -516,8 +628,8 @@ void DMainWindow::setShadowColor(const QColor &shadowColor)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setClipPath 设定裁剪路径
- * \~chinese \param clipPath　裁剪的路径
+  \brief DMainWindow::setClipPath 设定裁剪路径
+  \a clipPath　裁剪的路径
  */
 void DMainWindow::setClipPath(const QPainterPath &clipPath)
 {
@@ -531,8 +643,8 @@ void DMainWindow::setClipPath(const QPainterPath &clipPath)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setFrameMask 设定边框的mask区域
- * \~chinese \param frameMask mask区域
+  \brief DMainWindow::setFrameMask 设定边框的mask区域
+  \a frameMask mask区域
  */
 void DMainWindow::setFrameMask(const QRegion &frameMask)
 {
@@ -546,8 +658,8 @@ void DMainWindow::setFrameMask(const QRegion &frameMask)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setTranslucentBackground 设定时候擦除背景
- * \~chinese \param translucentBackground true擦除背景　false不擦除背景
+  \brief DMainWindow::setTranslucentBackground 设定时候擦除背景
+  \a translucentBackground true擦除背景　false不擦除背景
  */
 void DMainWindow::setTranslucentBackground(bool translucentBackground)
 {
@@ -561,8 +673,8 @@ void DMainWindow::setTranslucentBackground(bool translucentBackground)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setEnableSystemResize　设定是否允许系统调整窗口大小
- * \~chinese \param enableSystemResize　true允许系统调整　false不允许系统调整
+  \brief DMainWindow::setEnableSystemResize　设定是否允许系统调整窗口大小
+  \a enableSystemResize　true允许系统调整　false不允许系统调整
  */
 void DMainWindow::setEnableSystemResize(bool enableSystemResize)
 {
@@ -576,8 +688,8 @@ void DMainWindow::setEnableSystemResize(bool enableSystemResize)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setEnableSystemMove 设定时候允许系统移动窗口
- * \~chinese \param enableSystemMove　true允许移动　false不允许移动
+  \brief DMainWindow::setEnableSystemMove 设定时候允许系统移动窗口
+  \a enableSystemMove　true允许移动　false不允许移动
  */
 void DMainWindow::setEnableSystemMove(bool enableSystemMove)
 {
@@ -591,9 +703,9 @@ void DMainWindow::setEnableSystemMove(bool enableSystemMove)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setEnableBlurWindow　设置窗口模糊效果
- * \~shinese 开启此功能请设置setAttribute(Qt::WA_TranslucentBackground)
- * \~chinese \param enableBlurWindow true开启模糊效果　false关闭模糊效果
+  \brief DMainWindow::setEnableBlurWindow　设置窗口模糊效果
+  \~shinese 开启此功能请设置setAttribute(Qt::WA_TranslucentBackground)
+  \a enableBlurWindow true开启模糊效果　false关闭模糊效果
  */
 void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
 {
@@ -607,8 +719,9 @@ void DMainWindow::setEnableBlurWindow(bool enableBlurWindow)
 }
 
 /*!
- * \~chinese \brief DMainWindow::setAutoInputMaskByClipPath 通过裁剪区域自动设定mask
- * \~chinese \param autoInputMaskByClipPath true自动设定　false不自动设定
+  \brief 通过裁剪区域自动设定mask.
+
+  \a autoInputMaskByClipPath true自动设定　false不自动设定
  */
 void DMainWindow::setAutoInputMaskByClipPath(bool autoInputMaskByClipPath)
 {
@@ -622,9 +735,10 @@ void DMainWindow::setAutoInputMaskByClipPath(bool autoInputMaskByClipPath)
 }
 
 /*!
- * \~chinese \brief DMainWindow::sendMessage 发送消息
- * \~chinese \param icon 消息展示图标
- * \~chinese \param message　消息内容
+  \brief 发送浮动消息.
+
+  \a icon 消息展示图标
+  \a message　消息内容
  */
 void DMainWindow::sendMessage(const QIcon &icon, const QString &message)
 {
@@ -632,18 +746,15 @@ void DMainWindow::sendMessage(const QIcon &icon, const QString &message)
 }
 
 /*!
- * \~chinese \brief DMainWindow::sendMessage 发送消息
- * \~chinese \param message　DFloatingMessage消息
+  \brief 发送浮动消息.
+
+  \a message　DFloatingMessage消息
  */
 void DMainWindow::sendMessage(DFloatingMessage *message)
 {
     DMessageManager::instance()->sendMessage(this, message);
 }
 
-/*!
- * \~chinese \brief DMainWindow::setTitlebarShadowEnabled设定titleBar是否有阴影区域
- * \~chinese \param titlebarShadowEnabled true titleBar有阴影　false无阴影
- */
 void DMainWindow::setTitlebarShadowEnabled(bool titlebarShadowEnabled)
 {
     D_D(DMainWindow);
@@ -693,12 +804,17 @@ void DMainWindow::resizeEvent(QResizeEvent *event)
 
     d->updateTitleShadowGeometry();
 
+    if (sidebarWidget()) {
+        sidebarWidget()->resize(d->tb->size());
+        qInfo() << "sidebarWidget()->height" << sidebarWidget()->height() << d->tb->size();
+    }
     return QMainWindow::resizeEvent(event);
 }
 
 void DMainWindow::changeEvent(QEvent *event)
 {
-    if (event->type() == QEvent::WindowStateChange) {
+    if (event->type() == QEvent::WindowStateChange ||
+            event->type() == QEvent::StyleChange) {
         D_D(DMainWindow);
         d->updateTitleShadowGeometry();
     }
@@ -707,3 +823,5 @@ void DMainWindow::changeEvent(QEvent *event)
 }
 
 DWIDGET_END_NAMESPACE
+
+#include "moc_dmainwindow.cpp"
