@@ -1,19 +1,6 @@
-/*
- * Copyright (C) 2016 ~ 2017 Deepin Technology Co., Ltd.
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2016 - 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
 
 #include "dsettingswidgetfactory.h"
 
@@ -114,16 +101,18 @@ private:
 };
 
 /*!
- * \~chinese \class DSettingsWidgetFactory
- * \~chinese \brief DSettingsWidgetFactory是一个用于构造Deepin风格的设置对话框的控件。\n
- * \~chinese 对于每种控件，均由一个id和对应的构造函数来组成，DSettingsWidgetFactory内置了许多基础的控件，包括：\n
- * \~chinese checkbox/lineedit/combobox/spinbutton/buttongroup/radiogroup/slider等。
- * \~chinese
+  \class Dtk::Widget::DSettingsWidgetFactory
+  \inmodule dtkwidget
+  \brief DSettingsWidgetFactory是一个用于构造Deepin风格的设置对话框的控件.
+
+  对于每种控件，均由一个id和对应的构造函数来组成，DSettingsWidgetFactory内置了许多基础的控件，包括：
+  checkbox/lineedit/combobox/spinbutton/buttongroup/radiogroup/slider等。
+  
  */
 
 /*!
- * \~chinese \typedef DSettingsWidgetFactory::WidgetCreateHandler
- * \~chinese \brief 自定义的控件构建函数,一般接受一个 Dtk::Core::DSettingsOption 作为参数。\n
+  \typedef DSettingsWidgetFactory::WidgetCreateHandler
+  \brief 自定义的控件构建函数,一般接受一个 Dtk::Core::DSettingsOption 作为参数.
  */
 
 #define PRIVATE_PROPERTY_translateContext "_d_DSettingsWidgetFactory_translateContext"
@@ -138,12 +127,13 @@ static inline QString tr(const QByteArray &translateContext, const char *sourceT
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
- * \~chinese 左边为option的名称标签，右边为设置的自定义控件rightWidget
- * \~chinese \param option 设置项，包含改配置的名称
- * \~chinese \param rightWidget 自定义控件
- * \~chinese \return 生成的水平布局配置项控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
+  \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
+  左边为option的名称标签，右边为设置的自定义控件rightWidget.
+
+  \a option 设置项，包含改配置的名称
+  \a rightWidget 自定义控件
+  \return 生成的水平布局配置项控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
@@ -151,13 +141,14 @@ QWidget *DSettingsWidgetFactory::createTwoColumWidget(DTK_CORE_NAMESPACE::DSetti
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
- * \~chinese 左边为option的名称标签，右边为设置的自定义控件rightWidget, 可以通过translateContext设置翻译上下文。
- * \~chinese \param translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
- * \~chinese \param option 设置项，包含改配置的名称
- * \~chinese \param rightWidget 自定义控件
- * \~chinese \return 生成的水平布局配置项控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
+  \brief DSettingsWidgetFactory::createTwoColumWidget 返回一个水平布局的控件，
+  左边为option的名称标签，右边为设置的自定义控件rightWidget, 可以通过translateContext设置翻译上下文.
+
+  \a translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
+  \a option 设置项，包含改配置的名称
+  \a rightWidget 自定义控件
+  \return 生成的水平布局配置项控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createTwoColumWidget(Dtk::Core::DSettingsOption *option, QWidget *rightWidget)
  */
 QWidget *DSettingsWidgetFactory::createTwoColumWidget(const QByteArray &translateContext, DTK_CORE_NAMESPACE::DSettingsOption *option, QWidget *rightWidget)
 {
@@ -482,8 +473,6 @@ QPair<QWidget *, QWidget *> createSpinButtonOptionHandle(QObject *opt)
     rightWidget->setButtonSymbols(QAbstractSpinBox::PlusMinus);
     rightWidget->setObjectName("OptionDSpinBox");
     rightWidget->setAccessibleName("OptionDSpinBox");
-    rightWidget->setValue(option->value().toInt());
-
     if (option->data("max").isValid()) {
         rightWidget->setMaximum(option->data("max").toInt());
     }
@@ -491,6 +480,9 @@ QPair<QWidget *, QWidget *> createSpinButtonOptionHandle(QObject *opt)
         rightWidget->setMinimum(option->data("min").toInt());
     }
 
+    // The default range is 0-99. so we setMaximum/setMinimum first
+    rightWidget->setValue(option->value().toInt());
+
     auto translateContext = opt->property(PRIVATE_PROPERTY_translateContext).toByteArray();
 
     option->connect(rightWidget, static_cast<void (QSpinBox::*)(int value)>(&QSpinBox::valueChanged),
@@ -644,9 +636,10 @@ DSettingsWidgetFactory::~DSettingsWidgetFactory()
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::registerWidget 向Factory注册一种类型viewType。注册该类型后，可以通过在DSettings的DOption中，设置type为对应的viewType，这样Factory在构建viewType对应的控件时，会调用handler所指定的方法来构建。
- * \~chinese \param viewType 控件类型，建议为全局唯一的字符串，且不要和内部类型重复，参考 Dtk::Widget::DSettingsWidgetFactory
- * \~chinese \param handler 自定义的控件构建函数， 参考 Dtk::Widget::DSettingsWidgetFactory::WidgetCreateHandler
+  \brief DSettingsWidgetFactory::registerWidget 向Factory注册一种类型viewType。注册该类型后，可以通过在DSettings的DOption中，设置type为对应的viewType，这样Factory在构建viewType对应的控件时，会调用handler所指定的方法来构建.
+
+  \a viewType 控件类型，建议为全局唯一的字符串，且不要和内部类型重复，参考 Dtk::Widget::DSettingsWidgetFactory
+  \a handler 自定义的控件构建函数， 参考 Dtk::Widget::DSettingsWidgetFactory::WidgetCreateHandler
  */
 void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::function<WidgetCreateHandler> handler)
 {
@@ -661,21 +654,23 @@ void DSettingsWidgetFactory::registerWidget(const QString &viewType, std::functi
 }
 
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用，可以通过translateContext设置翻译上下文。
- * \~chinese \param option 需要构建的配置项
- * \~chinese \return 根据option的type属性创建的配置控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<Dtk::Core::DSettingsOption> option)
+  \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用，可以通过translateContext设置翻译上下文.
+
+  \a option 需要构建的配置项
+  \return 根据option的type属性创建的配置控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<Dtk::Core::DSettingsOption> option)
  */
 QWidget *DSettingsWidgetFactory::createWidget(QPointer<DTK_CORE_NAMESPACE::DSettingsOption> option)
 {
     return createWidget(QByteArray(), option);
 }
 /*!
- * \~chinese \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用,
- * \~chinese \param translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
- * \~chinese \param option 需要构建的配置项
- * \~chinese \return 根据option的type属性创建的配置控件
- * \~chinese \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(QPointer<Dtk::Core::DSettingsOption> option)
+  \brief DSettingsWidgetFactory::createWidget 创建一个option对应的配置控件，一般是需要自定义控件时使用.
+
+  \a translateContext 自定义的翻译上下文，参考 QCoreApplication::translate();
+  \a option 需要构建的配置项
+  \return 根据option的type属性创建的配置控件
+  \sa Dtk::Widget::DSettingsWidgetFactory::createWidget(QPointer<Dtk::Core::DSettingsOption> option)
  */
 QWidget *DSettingsWidgetFactory::createWidget(const QByteArray &translateContext, QPointer<DTK_CORE_NAMESPACE::DSettingsOption> option)
 {
