@@ -1,28 +1,13 @@
-/*
- * Copyright (C) 2017 ~ 2022 Deepin Technology Co., Ltd.
- *
- * Author:     zccrs <zccrs@live.com>
- *
- * Maintainer: zccrs <zhangjide@deepin.com>
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
- * any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program. If not, see <http://www.gnu.org/licenses/>.
- */
+// SPDX-FileCopyrightText: 2017 - 2023 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: LGPL-3.0-or-later
+
 #include "dstyleditemdelegate.h"
 #include "dobject_p.h"
 #include "dstyleoption.h"
 #include "dpalettehelper.h"
 #include "dstyle.h"
+#include "dsizemode.h"
 
 #include "dlistview.h"
 
@@ -37,6 +22,8 @@
 #include <QListWidget>
 #include <QPointer>
 #include <private/qlayoutengine_p.h>
+#include <DGuiApplicationHelper>
+#include <DDciIcon>
 
 Q_DECLARE_METATYPE(QMargins)
 
@@ -146,6 +133,7 @@ public:
     QSize maxSize;
     QMargins clickMargins;
     bool clickable = false;
+    DDciIcon dciIcon;
     QPointer<QWidget> widget = nullptr;
 
     qint8 colorType = -1;
@@ -363,14 +351,27 @@ public:
 
         // draw icon
         if (icon_size.isValid()) {
-            const QIcon &icon = action->icon();
             QRect icon_rect(QPoint(0, 0), icon_size);
 
             icon_rect.moveCenter(rect.center());
             icon_rect.moveLeft(rect.left());
 
-            auto modeStatePair = DStyle::toIconModeState(&option);
-            icon.paint(pa, icon_rect, Qt::AlignCenter, modeStatePair.first, modeStatePair.second);
+            if (action->dciIcon().isNull()) {
+                const QIcon &icon = action->icon();
+                auto modeStatePair = DStyle::toIconModeState(&option);
+                icon.paint(pa, icon_rect, Qt::AlignCenter, modeStatePair.first, modeStatePair.second);
+            } else {
+                DDciIcon dciicon = action->dciIcon();
+                DDciIcon::Mode mode = DStyle::toDciIconMode(&option);
+                auto appTheme = DGuiApplicationHelper::toColorType(option.palette);
+                DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+                DDciIconPalette palette{option.palette.color(cg, QPalette::WindowText), option.palette.color(cg, QPalette::Window),
+                                        option.palette.color(cg, QPalette::Highlight), option.palette.color(cg, QPalette::HighlightedText)};
+                if (option.state & QStyle::State_Selected)
+                    palette.setForeground(option.palette.color(cg, QPalette::HighlightedText));
+                dciicon.paint(pa, icon_rect, pa->device() ? pa->device()->devicePixelRatio()
+                                                          : qApp->devicePixelRatio(), theme, mode, Qt::AlignCenter, palette);
+            }
         }
 
         // draw text
@@ -813,6 +814,20 @@ QWidget *DViewItemAction::widget() const
     return d->widget;
 }
 
+void DViewItemAction::setDciIcon(const DDciIcon &dciIcon)
+{
+    D_D(DViewItemAction);
+
+    d->dciIcon = dciIcon;
+}
+
+DDciIcon DViewItemAction::dciIcon() const
+{
+    D_DC(DViewItemAction);
+
+    return d->dciIcon;
+}
+
 static QPalette::ColorRole getViewItemColorRole(const QModelIndex &index, int role)
 {
     const QVariant &value = index.data(role);
@@ -855,7 +870,6 @@ DStyledItemDelegate::DStyledItemDelegate(QAbstractItemView *parent)
 {
     //支持QAction的点击
     parent->viewport()->installEventFilter(this);
-    parent->installEventFilter(this);
 
     // 初始化 background type. 注意 setBackgroundType() 中有额外的处理操作，所以不能直接简单的修改默认值
     setBackgroundType(DStyledItemDelegate::RoundedBackground);
@@ -955,13 +969,31 @@ void DStyledItemDelegate::paint(QPainter *painter, const QStyleOptionViewItem &o
 
     // draw icon
     if (opt.features & QStyleOptionViewItem::HasDecoration) {
-        QIcon::Mode mode = QIcon::Normal;
-        if (!(opt.state & QStyle::State_Enabled))
-            mode = QIcon::Disabled;
-        else if (opt.state & QStyle::State_Selected)
-            mode = QIcon::Selected;
-        QIcon::State state = opt.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
-        opt.icon.paint(painter, iconRect, opt.decorationAlignment, mode, state);
+        QVariant icon = index.data(Qt::DecorationRole);
+        DDciIcon dciIcon;
+        if (icon.canConvert<DTK_GUI_NAMESPACE::DDciIcon>())
+            dciIcon = qvariant_cast<DDciIcon>(icon);
+
+        if (dciIcon.isNull()) {
+            QIcon::Mode mode = QIcon::Normal;
+            if (!(opt.state & QStyle::State_Enabled))
+                mode = QIcon::Disabled;
+            else if (opt.state & QStyle::State_Selected)
+                mode = QIcon::Selected;
+            QIcon::State state = opt.state & QStyle::State_Open ? QIcon::On : QIcon::Off;
+            opt.icon.paint(painter, iconRect, opt.decorationAlignment, mode, state);
+        } else {
+            DDciIcon::Mode mode = DStyle::toDciIconMode(&option);
+            auto appTheme = DGuiApplicationHelper::toColorType(option.palette);
+            DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+            DDciIconPalette palette{option.palette.color(cg, QPalette::WindowText), option.palette.color(cg, QPalette::Window),
+                                    option.palette.color(cg, QPalette::Highlight), option.palette.color(cg, QPalette::HighlightedText)};
+            if (option.state & QStyle::State_Selected)
+                palette.setForeground(opt.palette.color(cg, QPalette::HighlightedText));
+            dciIcon.paint(painter, iconRect, painter->device() ? painter->device()->devicePixelRatioF()
+                                                               : qApp->devicePixelRatio(),
+                          theme, mode, Qt::AlignCenter, palette);
+        }
     }
 
     // draw the text
@@ -1215,7 +1247,7 @@ void DStyledItemDelegate::setBackgroundType(DStyledItemDelegate::BackgroundType
         }
 
         int frame_margin = style->pixelMetric(static_cast<QStyle::PixelMetric>(DStyle::PM_FrameRadius));
-        d->margins += frame_margin;
+        d->margins += DSizeModeHelper::element(frame_margin / 2, frame_margin);
     }
 }
 
@@ -1244,6 +1276,25 @@ void DStyledItemDelegate::initStyleOption(QStyleOptionViewItem *option, const QM
 {
     QStyledItemDelegate::initStyleOption(option, index);
 
+    QVariant value = index.data(Qt::DecorationRole);
+    if (value.canConvert<DDciIcon>()) {
+        // The dciicon can not be set to opt.icon
+        auto dciIcon = qvariant_cast<DDciIcon>(value);
+        DDciIcon::Mode mode;
+        if (!(option->state & QStyle::State_Enabled))
+            mode = DDciIcon::Disabled;
+        else if (option->state & QStyle::State_Selected)
+            mode = DDciIcon::Pressed;
+        else
+            mode = DDciIcon::Normal;
+        auto appTheme = DGuiApplicationHelper::toColorType(option->palette);
+        DDciIcon::Theme theme = appTheme == DGuiApplicationHelper::LightType ? DDciIcon::Light : DDciIcon::Dark;
+        int actualSize = dciIcon.actualSize(option->decorationSize.width(), theme, mode);
+        // For highdpi icons actualSize might be larger than decorationSize, which we don't want. Clamp it to decorationSize.
+        option->decorationSize = QSize(qMin(option->decorationSize.width(), actualSize),
+                                       qMin(option->decorationSize.height(), actualSize));
+    }
+
     if (option->viewItemPosition == QStyleOptionViewItem::ViewItemPosition::Invalid) {
         const int rowCount =  index.model()->rowCount();
         if (rowCount == 1) {
@@ -1345,7 +1396,21 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
     default:
         break;
     }
-    if (object == parent()) {
+    const auto view = qobject_cast<QAbstractItemView*>(parent());
+    if (event->type() == QEvent::StyleChange && view) {
+        D_D(DStyledItemDelegate);
+        do {
+            if (d->margins.isNull())
+                break;
+
+            int frame_margin = DStyle::pixelMetric(view->style(), DStyle::PM_FrameRadius);
+            d->margins = QMargins() + DSizeModeHelper::element(frame_margin / 2, frame_margin);
+
+            // relayout to calculate size.
+            view->doItemsLayout();
+        } while (false);
+    }
+    if (view && object == view->viewport()) {
         static const QEvent::Type UpdateWidgetVisibleEvent(
                     static_cast<QEvent::Type>(QEvent::registerEventType()));
 
@@ -1353,7 +1418,7 @@ bool DStyledItemDelegate::eventFilter(QObject *object, QEvent *event)
             D_D(DStyledItemDelegate);
             if (d->readyRecordVisibleWidgetOfCurrentFrame()) {
                 auto updateEvent = new QEvent(UpdateWidgetVisibleEvent);
-                qApp->postEvent(parent(), updateEvent);
+                qApp->postEvent(view->viewport(), updateEvent);
             }
         } else if (event->type() == UpdateWidgetVisibleEvent) {
             D_D(DStyledItemDelegate);
@@ -1540,4 +1605,19 @@ QFont DStandardItem::font() const
     return getViewItemFont(index(), Dtk::ViewItemFontLevelRole);
 }
 
+void DStandardItem::setDciIcon(const DDciIcon &dciIcon)
+{
+    setData(QVariant::fromValue<DDciIcon>(dciIcon), Qt::DecorationRole);
+}
+
+DDciIcon DStandardItem::dciIcon() const
+{
+    return qvariant_cast<DDciIcon>(data(Qt::DecorationRole));
+}
+
+QStandardItem *DStandardItem::clone() const
+{
+    return new DStandardItem(*this);
+}
+
 DWIDGET_END_NAMESPACE
